<?php
require('header.php');

include('lib/db.php');
include('lib/utils.php');

/**
 * [session_start start a unique session for the current browser client]
 */
session_start();

$page = filter_input(INPUT_GET, 'page', FILTER_SANITIZE_URL);
$isPage = true;
if (!isset($page)) {
    $isPage = false;
    $page = "";
}

/**
 * form MUST have an hidden field named 'form' to enable proper routing
 */
$form = filter_input(INPUT_POST, 'form', FILTER_SANITIZE_URL);
$isForm = true;
if (!isset($form)) {
    $isForm = false;
    $form = "";
}

function get_action_type() {
    global $isPage, $isForm;

    if ($isPage && !$isForm && is_get_request()) {
        return "page";
    } elseif ($isForm && !$isPage && is_post_request()) {
        return "form";
    } elseif (!$isPage && !$isForm && is_get_request()){
        return "empty";
    } else {
        return "unknown";
    }
}

function get_url_action() {
    global $page, $form;

    if (get_action_type() === "page") {
        return $page;
    } elseif (get_action_type() === "form") {
        return $form;
    } elseif (get_action_type() === "empty") {
        return "";
    } elseif (get_action_type() === "unknown") {
        die('Cannot get a valid action from URL parameters');
    }
}

/**
 * [validate_url_action validate if the current page is a valid site actions]
 * @param  [string] $page [the viewed page name]
 * @return [string]       [the valid matching action or the default action
 *                         if the action name do not exist ]
 */
function validate_url_action($action_name)
{
    global $configs;

    foreach ($configs['actions'] as $action) {
        if (strcmp($action_name, $action) === 0) {
            // The actions list can't have duplicated entries
            return $action;
        }
    }
    // Return the default action
    return $configs['actions'][0];
}

function display_action($action_name)
{
    global $configs, $isPage, $isForm;

    $found_action = false;
    foreach ($configs['actions'] as $action) {
        if (strcmp($action_name, $action) === 0) {
            // HTTP GET case
            if (get_action_type() === "page" || get_action_type() === "empty") {
                include($action . ".php");
            // HTTP POST case
            } elseif (get_action_type() === "form") {
                include("form" . $action . ".php");
            } else {
                echo "Unknown error in action displaying";
            }
            $found_action = true;
            break;
        }
    }
    if (!$found_action) {
        echo "Action to display do not exist";
    }
}

$url_action = get_url_action();
$action = validate_url_action($url_action);
display_action($action);

session_destroy();

require('footer.html');
?>
